.. Digital Rock Data documentation master file, created by
   sphinx-quickstart on Sun Apr 24 12:53:09 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Digital Rock Data's documentation!
=============================================

Some words.

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   drd


.. toctree::
   :maxdepth: 2
   :caption: Example galleries

   auto_examples/index